==================
icemac.addressbook
==================

.. image:: https://travis-ci.com/icemac/icemac.addressbook.svg?branch=master
   :target: https://travis-ci.com/icemac/icemac.addressbook

.. image:: https://coveralls.io/repos/github/icemac/icemac.addressbook/badge.svg?branch=master
   :target: https://coveralls.io/github/icemac/icemac.addressbook?branch=master

.. image:: https://img.shields.io/pypi/v/icemac.addressbook.svg
   :target: https://pypi.python.org/pypi/icemac.addressbook/
   :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/icemac.addressbook.svg
   :target: https://pypi.org/project/icemac.addressbook/
   :alt: Supported Python versions

.. image:: https://readthedocs.org/projects/zodb/badge/?version=latest
   :target: https://icemacaddressbook.readthedocs.io/en/latest/
   :alt: Documentation status

Purpose:
    Store, search and export addresses and phone numbers using a web application.
Status:
    stable version, used in production; some features might be added in future

Copyright (c) 2008-2020 Michael Howitz

This package is licensed under the MIT License, see LICENSE.TXT inside the
package.

* Features_
* Screenshots_
* Download_
* Installation_
* Update_
* `Run the tests`_
* `Run the application`_
* `User management`_
* `Operations`_
* `To do`_

.. _Features : https://icemacaddressbook.readthedocs.io/en/latest/features.html
.. _Screenshots : https://icemacaddressbook.readthedocs.io/en/latest/screenshots.html
.. _Download : https://pypi.org/project/icemac.addressbook#files
.. _Installation : https://icemacaddressbook.readthedocs.io/en/latest/installation.html
.. _`User management` : https://icemacaddressbook.readthedocs.io/en/latest/usermanagement.html
.. _`Update` : https://icemacaddressbook.readthedocs.io/en/latest/update.html
.. _`Run the tests`: https://icemacaddressbook.readthedocs.io/en/latest/runthetests.html
.. _`Run the application` : https://icemacaddressbook.readthedocs.io/en/latest/runtheapplication.html
.. _`To do` : https://icemacaddressbook.readthedocs.io/en/latest/todo.html
.. _`Operations` : https://icemacaddressbook.readthedocs.io/en/latest/operations.html
